[ofa-general] [PATCH] opensm: Convert unicast LIDs in long messages from hex to decimal

Hal Rosenstock hrosenstock at xsigo.com
Fri Jun 27 08:14:46 PDT 2008


opensm: Convert unicast LIDs in long messages from hex to decimal

First pass; a few more changes related to this separately later

Signed-off-by: Hal Rosenstock <hal at xsigo.com>

diff --git a/opensm/opensm/osm_console.c b/opensm/opensm/osm_console.c
index 7f0b00f..d3206e5 100644
--- a/opensm/opensm/osm_console.c
+++ b/opensm/opensm/osm_console.c
@@ -438,7 +438,7 @@ static void querylid_parse(char **p_last, osm_opensm_t * p_osm, FILE * out)
 	if (!p_port)
 		goto invalid_lid;
 
-	fprintf(out, "Query results for LID %d\n", lid);
+	fprintf(out, "Query results for LID %u\n", lid);
 	fprintf(out,
 		"   GUID                : 0x%016" PRIx64 "\n"
 		"   Node Desc           : %s\n"
diff --git a/opensm/opensm/osm_drop_mgr.c b/opensm/opensm/osm_drop_mgr.c
index 2d8d6e9..a7b2553 100644
--- a/opensm/opensm/osm_drop_mgr.c
+++ b/opensm/opensm/osm_drop_mgr.c
@@ -196,7 +196,7 @@ static void __osm_drop_mgr_remove_port(osm_sm_t * sm, IN osm_port_t * p_port)
 	osm_port_get_lid_range_ho(p_port, &min_lid_ho, &max_lid_ho);
 
 	OSM_LOG(sm->p_log, OSM_LOG_VERBOSE,
-		"Clearing abandoned LID range [0x%X,0x%X]\n",
+		"Clearing abandoned LID range [%u,%u]\n",
 		min_lid_ho, max_lid_ho);
 
 	p_port_lid_tbl = &sm->p_subn->port_lid_tbl;
@@ -254,7 +254,7 @@ static void __osm_drop_mgr_remove_port(osm_sm_t * sm, IN osm_port_t * p_port)
 	if (osm_log_is_active(sm->p_log, OSM_LOG_INFO)) {
 		OSM_LOG(sm->p_log, OSM_LOG_INFO,
 			"Removed port with GUID:0x%016" PRIx64
-			" LID range [0x%X,0x%X] of node:%s\n",
+			" LID range [%u, %u] of node:%s\n",
 			cl_ntoh64(port_gid.unicast.interface_id),
 			min_lid_ho, max_lid_ho,
 			p_node ? p_node->print_desc : "UNKNOWN");
diff --git a/opensm/opensm/osm_dump.c b/opensm/opensm/osm_dump.c
index 60c6d25..9447cc8 100644
--- a/opensm/opensm/osm_dump.c
+++ b/opensm/opensm/osm_dump.c
@@ -330,7 +330,7 @@ static void dump_ucast_lfts(cl_map_item_t *p_map_item, FILE *file, void *cxt)
 	uint16_t lid;
 	uint8_t port;
 
-	fprintf(file, "Unicast lids [0x0-0x%x] of switch Lid %u guid 0x%016"
+	fprintf(file, "Unicast lids [0-%u] of switch Lid %u guid 0x%016"
 		PRIx64 " (\'%s\'):\n",
 		max_lid, cl_ntoh16(osm_node_get_base_lid(p_node, 0)),
 		cl_ntoh64(osm_node_get_node_guid(p_node)), p_node->print_desc);
diff --git a/opensm/opensm/osm_helper.c b/opensm/opensm/osm_helper.c
index 1b20638..f91e1e8 100644
--- a/opensm/opensm/osm_helper.c
+++ b/opensm/opensm/osm_helper.c
@@ -740,8 +740,8 @@ osm_dump_port_info(IN osm_log_t * const p_log,
 			"\t\t\t\tport_guid...............0x%016" PRIx64 "\n"
 			"\t\t\t\tm_key...................0x%016" PRIx64 "\n"
 			"\t\t\t\tsubnet_prefix...........0x%016" PRIx64 "\n"
-			"\t\t\t\tbase_lid................0x%X\n"
-			"\t\t\t\tmaster_sm_base_lid......0x%X\n"
+			"\t\t\t\tbase_lid................%u\n"
+			"\t\t\t\tmaster_sm_base_lid......%u\n"
 			"\t\t\t\tcapability_mask.........0x%X\n"
 			"\t\t\t\tdiag_code...............0x%X\n"
 			"\t\t\t\tm_key_lease_period......0x%X\n"
@@ -824,14 +824,14 @@ osm_dump_portinfo_record(IN osm_log_t * const p_log,
 		osm_log(p_log, log_level,
 			"PortInfo Record dump:\n"
 			"\t\t\t\tRID\n"
-			"\t\t\t\tEndPortLid..............0x%X\n"
+			"\t\t\t\tEndPortLid..............%u\n"
 			"\t\t\t\tPortNum.................0x%X\n"
 			"\t\t\t\tReserved................0x%X\n"
 			"\t\t\t\tPortInfo dump:\n"
 			"\t\t\t\tm_key...................0x%016" PRIx64 "\n"
 			"\t\t\t\tsubnet_prefix...........0x%016" PRIx64 "\n"
-			"\t\t\t\tbase_lid................0x%X\n"
-			"\t\t\t\tmaster_sm_base_lid......0x%X\n"
+			"\t\t\t\tbase_lid................%u\n"
+			"\t\t\t\tmaster_sm_base_lid......%u\n"
 			"\t\t\t\tcapability_mask.........0x%X\n"
 			"\t\t\t\tdiag_code...............0x%X\n"
 			"\t\t\t\tm_key_lease_period......0x%X\n"
@@ -911,7 +911,7 @@ osm_dump_guidinfo_record(IN osm_log_t * const p_log,
 		osm_log(p_log, log_level,
 			"GUIDInfo Record dump:\n"
 			"\t\t\t\tRID\n"
-			"\t\t\t\tLid.....................0x%X\n"
+			"\t\t\t\tLid.....................%u\n"
 			"\t\t\t\tBlockNum................0x%X\n"
 			"\t\t\t\tReserved................0x%X\n"
 			"\t\t\t\tGUIDInfo dump:\n"
@@ -996,7 +996,7 @@ osm_dump_node_record(IN osm_log_t * const p_log,
 		osm_log(p_log, log_level,
 			"Node Record dump:\n"
 			"\t\t\t\tRID\n"
-			"\t\t\t\tLid.....................0x%X\n"
+			"\t\t\t\tLid.....................%u\n"
 			"\t\t\t\tReserved................0x%X\n"
 			"\t\t\t\tNodeInfo dump:\n"
 			"\t\t\t\tbase_version............0x%X\n"
@@ -1047,7 +1047,7 @@ osm_dump_path_record(IN osm_log_t * const p_log,
 			"\t\t\t\tsgid....................0x%016" PRIx64 " : "
 			"0x%016" PRIx64 "\n"
 			"\t\t\t\tdlid....................0x%X\n"
-			"\t\t\t\tslid....................0x%X\n"
+			"\t\t\t\tslid....................%u\n"
 			"\t\t\t\thop_flow_raw............0x%X\n"
 			"\t\t\t\ttclass..................0x%X\n"
 			"\t\t\t\tnum_path_revers.........0x%X\n"
@@ -1322,8 +1322,8 @@ osm_dump_inform_info(IN osm_log_t * const p_log,
 				"InformInfo dump:\n"
 				"\t\t\t\tgid.....................0x%016" PRIx64
 				" : 0x%016" PRIx64 "\n"
-				"\t\t\t\tlid_range_begin.........0x%X\n"
-				"\t\t\t\tlid_range_end...........0x%X\n"
+				"\t\t\t\tlid_range_begin.........%u\n"
+				"\t\t\t\tlid_range_end...........%u\n"
 				"\t\t\t\tis_generic..............0x%X\n"
 				"\t\t\t\tsubscribe...............0x%X\n"
 				"\t\t\t\ttrap_type...............0x%X\n"
@@ -1346,8 +1346,8 @@ osm_dump_inform_info(IN osm_log_t * const p_log,
 				"InformInfo dump:\n"
 				"\t\t\t\tgid.....................0x%016" PRIx64
 				" : 0x%016" PRIx64 "\n"
-				"\t\t\t\tlid_range_begin.........0x%X\n"
-				"\t\t\t\tlid_range_end...........0x%X\n"
+				"\t\t\t\tlid_range_begin.........%u\n"
+				"\t\t\t\tlid_range_end...........%u\n"
 				"\t\t\t\tis_generic..............0x%X\n"
 				"\t\t\t\tsubscribe...............0x%X\n"
 				"\t\t\t\ttrap_type...............0x%X\n"
@@ -1395,8 +1395,8 @@ osm_dump_inform_info_record(IN osm_log_t * const p_log,
 				"\t\t\t\tInformInfo dump:\n"
 				"\t\t\t\tgid.....................0x%016" PRIx64
 				" : 0x%016" PRIx64 "\n"
-				"\t\t\t\tlid_range_begin.........0x%X\n"
-				"\t\t\t\tlid_range_end...........0x%X\n"
+				"\t\t\t\tlid_range_begin.........%u\n"
+				"\t\t\t\tlid_range_end...........%u\n"
 				"\t\t\t\tis_generic..............0x%X\n"
 				"\t\t\t\tsubscribe...............0x%X\n"
 				"\t\t\t\ttrap_type...............0x%X\n"
@@ -1433,8 +1433,8 @@ osm_dump_inform_info_record(IN osm_log_t * const p_log,
 				"\t\t\t\tInformInfo dump:\n"
 				"\t\t\t\tgid.....................0x%016" PRIx64
 				" : 0x%016" PRIx64 "\n"
-				"\t\t\t\tlid_range_begin.........0x%X\n"
-				"\t\t\t\tlid_range_end...........0x%X\n"
+				"\t\t\t\tlid_range_begin.........%u\n"
+				"\t\t\t\tlid_range_end...........%u\n"
 				"\t\t\t\tis_generic..............0x%X\n"
 				"\t\t\t\tsubscribe...............0x%X\n"
 				"\t\t\t\ttrap_type...............0x%X\n"
@@ -1475,10 +1475,10 @@ osm_dump_link_record(IN osm_log_t * const p_log,
 	if (osm_log_is_active(p_log, log_level)) {
 		osm_log(p_log, log_level,
 			"Link Record dump:\n"
-			"\t\t\t\tfrom_lid................0x%X\n"
+			"\t\t\t\tfrom_lid................%u\n"
 			"\t\t\t\tfrom_port_num...........0x%X\n"
 			"\t\t\t\tto_port_num.............0x%X\n"
-			"\t\t\t\tto_lid..................0x%X\n"
+			"\t\t\t\tto_lid..................%u\n"
 			"",
 			cl_ntoh16(p_lr->from_lid),
 			p_lr->from_port_num,
@@ -1533,7 +1533,7 @@ osm_dump_switch_info_record(IN osm_log_t * const p_log,
 		osm_log(p_log, log_level,
 			"SwitchInfo Record dump:\n"
 			"\t\t\t\tRID\n"
-			"\t\t\t\tlid.....................0x%X\n"
+			"\t\t\t\tlid.....................%u\n"
 			"\t\t\t\tSwitchInfo dump:\n"
 			"\t\t\t\tlin_cap.................0x%X\n"
 			"\t\t\t\trand_cap................0x%X\n"
@@ -1686,7 +1686,7 @@ osm_dump_sm_info_record(IN osm_log_t * const p_log,
 		osm_log(p_log, OSM_LOG_DEBUG,
 			"SMInfo Record dump:\n"
 			"\t\t\t\tRID\n"
-			"\t\t\t\tLid.....................0x%X\n"
+			"\t\t\t\tLid.....................%u\n"
 			"\t\t\t\tReserved................0x%X\n"
 			"\t\t\t\tSMInfo dump:\n"
 			"\t\t\t\tguid....................0x%016" PRIx64 "\n"
@@ -1735,7 +1735,7 @@ osm_dump_notice(IN osm_log_t * const p_log,
 				break;
 			case 128:
 				sprintf(buff,
-					"\t\t\t\tsw_lid...................0x%04X\n",
+					"\t\t\t\tsw_lid...................%u\n",
 					cl_ntoh16(p_ntci->data_details.ntc_128.
 						  sw_lid));
 				break;
@@ -1743,7 +1743,7 @@ osm_dump_notice(IN osm_log_t * const p_log,
 			case 130:
 			case 131:
 				sprintf(buff,
-					"\t\t\t\tlid......................0x%04X\n"
+					"\t\t\t\tlid......................%u\n"
 					"\t\t\t\tport_num.................%u\n",
 					cl_ntoh16(p_ntci->data_details.
 						  ntc_129_131.lid),
@@ -1752,7 +1752,7 @@ osm_dump_notice(IN osm_log_t * const p_log,
 				break;
 			case 144:
 				sprintf(buff,
-					"\t\t\t\tlid......................0x%04x\n"
+					"\t\t\t\tlid......................%u\n"
 					"\t\t\t\tnew_cap_mask.............0x%08x\n",
 					cl_ntoh16(p_ntci->data_details.ntc_144.
 						  lid),
@@ -1761,7 +1761,7 @@ osm_dump_notice(IN osm_log_t * const p_log,
 				break;
 			case 145:
 				sprintf(buff,
-					"\t\t\t\tlid......................0x%04X\n"
+					"\t\t\t\tlid......................%u\n"
 					"\t\t\t\tnew_sys_guid.............0x%016"
 					PRIx64 "\n",
 					cl_ntoh16(p_ntci->data_details.ntc_145.
@@ -1853,8 +1853,8 @@ osm_dump_dr_smp(IN osm_log_t * const p_log,
 
 		if (p_smp->mgmt_class == IB_MCLASS_SUBN_DIR) {
 			sprintf(line,
-				"\t\t\t\tdr_slid.................0x%X\n"
-				"\t\t\t\tdr_dlid.................0x%X\n",
+				"\t\t\t\tdr_slid.................%u\n"
+				"\t\t\t\tdr_dlid.................%u\n",
 				cl_ntoh16(p_smp->dr_slid),
 				cl_ntoh16(p_smp->dr_dlid)
 			    );
diff --git a/opensm/opensm/osm_inform.c b/opensm/opensm/osm_inform.c
index 1a4f18f..e6146f7 100644
--- a/opensm/opensm/osm_inform.c
+++ b/opensm/opensm/osm_inform.c
@@ -323,8 +323,8 @@ static ib_api_status_t __osm_send_report(IN osm_infr_t * p_infr_rec,	/* the info
 
 	/* it is better to use LIDs since the GIDs might not be there for SMI traps */
 	OSM_LOG(p_log, OSM_LOG_DEBUG,
-		"Forwarding Notice Event from LID:0x%X"
-		" to InformInfo LID: 0x%X TID:0x%X\n",
+		"Forwarding Notice Event from LID:%u"
+		" to InformInfo LID: %u TID:0x%X\n",
 		cl_ntoh16(p_ntc->issuer_lid),
 		cl_ntoh16(p_infr_rec->report_addr.dest_lid), trap_fwd_trans_id);
 
@@ -422,7 +422,7 @@ __match_notice_to_inf_rec(IN cl_list_item_t * const p_list_item,
 			    || (cl_hton16(p_ntc->issuer_lid) >
 				cl_hton16(p_ii->lid_range_end))) {
 				OSM_LOG(p_log, OSM_LOG_DEBUG,
-					"Mismatch by LID Range. Needed: 0x%X <= 0x%X <= 0x%X\n",
+					"Mismatch by LID Range. Needed: %u <= %u <= %u\n",
 					cl_hton16(p_ii->lid_range_begin),
 					cl_hton16(p_ntc->issuer_lid),
 					cl_hton16(p_ii->lid_range_end)
@@ -519,7 +519,7 @@ __match_notice_to_inf_rec(IN cl_list_item_t * const p_list_item,
 			      cl_ntoh16(p_infr_rec->report_addr.dest_lid));
 	if (!p_dest_port) {
 		OSM_LOG(p_log, OSM_LOG_INFO,
-			"Cannot find destination port with LID:0x%04x\n",
+			"Cannot find destination port with LID:%u\n",
 			cl_ntoh16(p_infr_rec->report_addr.dest_lid));
 		goto Exit;
 	}
@@ -582,7 +582,7 @@ osm_report_notice(IN osm_log_t * const p_log,
 	if (ib_notice_is_generic(p_ntc)) {
 		OSM_LOG(p_log, OSM_LOG_INFO,
 			"Reporting Generic Notice type:%u num:%u"
-			" from LID:0x%04X GID:0x%016" PRIx64
+			" from LID:%u GID:0x%016" PRIx64
 			",0x%016" PRIx64 "\n",
 			ib_notice_get_type(p_ntc),
 			cl_ntoh16(p_ntc->g_or_v.generic.trap_num),
@@ -593,7 +593,7 @@ osm_report_notice(IN osm_log_t * const p_log,
 	} else {
 		OSM_LOG(p_log, OSM_LOG_INFO,
 			"Reporting Vendor Notice type:%u vend:%u dev:%u"
-			" from LID:0x%04X GID:0x%016" PRIx64
+			" from LID:%u GID:0x%016" PRIx64
 			",0x%016" PRIx64 "\n",
 			ib_notice_get_type(p_ntc),
 			cl_ntoh32(ib_notice_get_vend_id(p_ntc)),
diff --git a/opensm/opensm/osm_lid_mgr.c b/opensm/opensm/osm_lid_mgr.c
index af8f7b3..d66ced3 100644
--- a/opensm/opensm/osm_lid_mgr.c
+++ b/opensm/opensm/osm_lid_mgr.c
@@ -173,7 +173,7 @@ static void __osm_lid_mgr_validate_db(IN osm_lid_mgr_t * p_mgr)
 			    || (p_item->guid == 0)
 			    || (max_lid > p_mgr->p_subn->max_ucast_lid_ho)) {
 				OSM_LOG(p_mgr->p_log, OSM_LOG_ERROR, "ERR 0312: "
-					"Illegal LID range [0x%x:0x%x] for "
+					"Illegal LID range [%u:%u] for "
 					"guid:0x%016" PRIx64 "\n", min_lid,
 					max_lid, p_item->guid);
 				lids_ok = FALSE;
@@ -182,7 +182,7 @@ static void __osm_lid_mgr_validate_db(IN osm_lid_mgr_t * p_mgr)
 				/* check that if the lids define a range that is valid
 				   for the current LMC mask */
 				OSM_LOG(p_mgr->p_log, OSM_LOG_ERROR, "ERR 0313: "
-					"LID range [0x%x:0x%x] for guid:0x%016"
+					"LID range [%u:%u] for guid:0x%016"
 					PRIx64
 					" is not aligned according to mask:0x%04x\n",
 					min_lid, max_lid, p_item->guid,
@@ -774,13 +774,13 @@ __osm_lid_mgr_get_port_lid(IN osm_lid_mgr_t * const p_mgr,
 		if (min_lid == cl_ntoh16(osm_port_get_base_lid(p_port))) {
 			OSM_LOG(p_mgr->p_log, OSM_LOG_DEBUG,
 				"0x%016" PRIx64
-				" matches its known lid:0x%04x\n", guid,
+				" matches its known lid:%u\n", guid,
 				min_lid);
 			goto Exit;
 		} else {
 			OSM_LOG(p_mgr->p_log, OSM_LOG_DEBUG,
-				"0x%016" PRIx64 " with lid:0x%04x "
-				"does not match its known lid:0x%04x\n",
+				"0x%016" PRIx64 " with lid:%u "
+				"does not match its known lid:%u\n",
 				guid, cl_ntoh16(osm_port_get_base_lid(p_port)),
 				min_lid);
 			__osm_lid_mgr_cleanup_discovered_port_lid_range(p_mgr,
@@ -1179,7 +1179,7 @@ __osm_lid_mgr_process_our_sm_node(IN osm_lid_mgr_t * const p_mgr)
 	 */
 	__osm_lid_mgr_get_port_lid(p_mgr, p_port, &min_lid_ho, &max_lid_ho);
 	OSM_LOG(p_mgr->p_log, OSM_LOG_DEBUG,
-		"Current base LID is 0x%X\n", min_lid_ho);
+		"Current base LID is %u\n", min_lid_ho);
 	/*
 	   Update subnet object.
 	 */
@@ -1189,7 +1189,7 @@ __osm_lid_mgr_process_our_sm_node(IN osm_lid_mgr_t * const p_mgr)
 	if (osm_log_is_active(p_mgr->p_log, OSM_LOG_VERBOSE))
 		OSM_LOG(p_mgr->p_log, OSM_LOG_VERBOSE,
 			"Assigning SM's port 0x%016" PRIx64
-			"\n\t\t\t\tto LID range [0x%X,0x%X]\n",
+			"\n\t\t\t\tto LID range [%u,%u]\n",
 			cl_ntoh64(osm_port_get_guid(p_port)),
 			min_lid_ho, max_lid_ho);
 
@@ -1301,7 +1301,7 @@ osm_signal_t osm_lid_mgr_process_subnet(IN osm_lid_mgr_t * const p_mgr)
 		   if required */
 		OSM_LOG(p_mgr->p_log, OSM_LOG_VERBOSE,
 			"Assigned port 0x%016" PRIx64
-			", LID [0x%X,0x%X]\n", cl_ntoh64(port_guid),
+			", LID [%u,%u]\n", cl_ntoh64(port_guid),
 			min_lid_ho, max_lid_ho);
 
 		/* the proc returns the fact it sent a set port info */
diff --git a/opensm/opensm/osm_mcast_mgr.c b/opensm/opensm/osm_mcast_mgr.c
index c3167a8..7ab05c3 100644
--- a/opensm/opensm/osm_mcast_mgr.c
+++ b/opensm/opensm/osm_mcast_mgr.c
@@ -466,7 +466,7 @@ __osm_mcast_mgr_subdivide(osm_sm_t * sm,
 				"Error routing MLID 0x%X through switch 0x%"
 				PRIx64 "\n"
 				"\t\t\t\tNo multicast paths from this switch for port "
-				"with LID 0x%X\n", mlid_ho, node_guid_ho,
+				"with LID %u\n", mlid_ho, node_guid_ho,
 				cl_ntoh16(osm_port_get_base_lid
 					  (p_wobj->p_port)));
 
@@ -481,7 +481,7 @@ __osm_mcast_mgr_subdivide(osm_sm_t * sm,
 				"Error routing MLID 0x%X through switch 0x%"
 				PRIx64 "\n"
 				"\t\t\t\tNo multicast paths from this switch to port "
-				"with LID 0x%X\n", mlid_ho, node_guid_ho,
+				"with LID %u\n", mlid_ho, node_guid_ho,
 				cl_ntoh16(osm_port_get_base_lid
 					  (p_wobj->p_port)));
 
@@ -567,7 +567,7 @@ static osm_mtree_node_t *__osm_mcast_mgr_branch(osm_sm_t * sm,
 
 	if (depth >= 64) {
 		OSM_LOG(sm->p_log, OSM_LOG_ERROR,
-			"Maximal hops number is reached MLID 0x%x."
+			"Maximal hops number is reached for MLID 0x%x."
 			" Break processing.", mlid_ho);
 		__osm_mcast_mgr_purge_list(sm, p_list);
 		goto Exit;
diff --git a/opensm/opensm/osm_perfmgr.c b/opensm/opensm/osm_perfmgr.c
index 315a065..9892335 100644
--- a/opensm/opensm/osm_perfmgr.c
+++ b/opensm/opensm/osm_perfmgr.c
@@ -1113,7 +1113,7 @@ static void osm_pc_rcv_process(void *context, void *data)
 		ib_api_status_t status;
 
 		OSM_LOG(pm->log, OSM_LOG_VERBOSE,
-			"Redirection to LID 0x%x "
+			"Redirection to LID %u "
 			"GID 0x%016" PRIx64 " : 0x%016" PRIx64
 			" QP 0x%x received\n",
 			cl_ntoh16(cpi->redir_lid),
diff --git a/opensm/opensm/osm_port_info_rcv.c b/opensm/opensm/osm_port_info_rcv.c
index c2ddfb0..2e3d94e 100644
--- a/opensm/opensm/osm_port_info_rcv.c
+++ b/opensm/opensm/osm_port_info_rcv.c
@@ -94,8 +94,8 @@ static void pi_rcv_check_and_fix_lid(osm_log_t *log, ib_port_info_t * const pi,
 {
 	if (cl_ntoh16(pi->base_lid) > IB_LID_UCAST_END_HO) {
 		OSM_LOG(log, OSM_LOG_ERROR, "ERR 0F04: "
-			"Got invalid base LID 0x%x from the network. "
-			"Corrected to 0x%x.\n", cl_ntoh16(pi->base_lid),
+			"Got invalid base LID %u from the network. "
+			"Corrected to %u.\n", cl_ntoh16(pi->base_lid),
 			cl_ntoh16(p->port_info.base_lid));
 		pi->base_lid = p->port_info.base_lid;
 	}
diff --git a/opensm/opensm/osm_sa_guidinfo_record.c b/opensm/opensm/osm_sa_guidinfo_record.c
index 7760f42..aaf4d6c 100644
--- a/opensm/opensm/osm_sa_guidinfo_record.c
+++ b/opensm/opensm/osm_sa_guidinfo_record.c
@@ -140,7 +140,7 @@ __osm_sa_gir_create_gir(IN osm_sa_t * sa,
 
 	if (osm_log_is_active(sa->p_log, OSM_LOG_DEBUG)) {
 		OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-			"Looking for GUIDRecord with LID: 0x%X GUID:0x%016"
+			"Looking for GUIDRecord with LID: %u GUID:0x%016"
 			PRIx64 "\n", cl_ntoh16(match_lid),
 			cl_ntoh64(match_port_guid)
 		    );
@@ -203,7 +203,7 @@ __osm_sa_gir_create_gir(IN osm_sa_t * sa,
 			 */
 			if (osm_log_is_active(sa->p_log, OSM_LOG_DEBUG)) {
 				OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-					"Comparing LID: 0x%X <= 0x%X <= 0x%X\n",
+					"Comparing LID: %u <= %u <= %u\n",
 					base_lid_ho, match_lid_ho, max_lid_ho);
 			}
 
diff --git a/opensm/opensm/osm_sa_informinfo.c b/opensm/opensm/osm_sa_informinfo.c
index 798f5db..3bb2295 100644
--- a/opensm/opensm/osm_sa_informinfo.c
+++ b/opensm/opensm/osm_sa_informinfo.c
@@ -160,7 +160,7 @@ __validate_ports_access_rights(IN osm_sa_t * sa,
 			} else {
 				/* lid requested is out of range */
 				OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 4302: "
-					"Given LID (0x%X) is out of range:0x%X\n",
+					"Given LID (%u) is out of range:%u\n",
 					lid, cl_ptr_vector_get_size(p_tbl));
 				valid = FALSE;
 				goto Exit;
@@ -457,7 +457,7 @@ osm_infr_rcv_process_set_method(IN osm_sa_t * sa,
 		cl_plock_release(sa->p_lock);
 
 		OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 4308 "
-			"Subscribe Request from unknown LID: 0x%04X\n",
+			"Subscribe Request from unknown LID: %u\n",
 			cl_ntoh16(p_madw->mad_addr.dest_lid));
 		osm_sa_send_error(sa, p_madw, IB_SA_MAD_STATUS_REQ_INVALID);
 		goto Exit;
diff --git a/opensm/opensm/osm_sa_lft_record.c b/opensm/opensm/osm_sa_lft_record.c
index f4b9b6e..fd7ccf6 100644
--- a/opensm/opensm/osm_sa_lft_record.c
+++ b/opensm/opensm/osm_sa_lft_record.c
@@ -182,7 +182,7 @@ __osm_lftr_rcv_by_comp_mask(IN cl_map_item_t * const p_map_item,
 	/* compare the lids - if required */
 	if (comp_mask & IB_LFTR_COMPMASK_LID) {
 		OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-			"Comparing lid:0x%02X to port lid range: 0x%02X .. 0x%02X\n",
+			"Comparing lid:%u to port lid range: %u .. %u\n",
 			cl_ntoh16(p_rcvd_rec->lid), min_lid_ho, max_lid_ho);
 		/* ok we are ready for range check */
 		if (min_lid_ho > cl_ntoh16(p_rcvd_rec->lid) ||
diff --git a/opensm/opensm/osm_sa_link_record.c b/opensm/opensm/osm_sa_link_record.c
index 0b761ba..f08eee1 100644
--- a/opensm/opensm/osm_sa_link_record.c
+++ b/opensm/opensm/osm_sa_link_record.c
@@ -404,7 +404,7 @@ __osm_lr_rcv_get_end_points(IN osm_sa_t * sa,
 			   Return an error response to the client.
 			 */
 			OSM_LOG(sa->p_log, OSM_LOG_VERBOSE,
-				"No source port with LID = 0x%X\n",
+				"No source port with LID %u\n",
 				cl_ntoh16(p_lr->from_lid));
 
 			sa_status = IB_SA_MAD_STATUS_NO_RECORDS;
@@ -423,7 +423,7 @@ __osm_lr_rcv_get_end_points(IN osm_sa_t * sa,
 			   Return an error response to the client.
 			 */
 			OSM_LOG(sa->p_log, OSM_LOG_VERBOSE,
-				"No dest port with LID = 0x%X\n",
+				"No dest port with LID %u\n",
 				cl_ntoh16(p_lr->to_lid));
 
 			sa_status = IB_SA_MAD_STATUS_NO_RECORDS;
diff --git a/opensm/opensm/osm_sa_mft_record.c b/opensm/opensm/osm_sa_mft_record.c
index 57350a6..433f717 100644
--- a/opensm/opensm/osm_sa_mft_record.c
+++ b/opensm/opensm/osm_sa_mft_record.c
@@ -188,7 +188,7 @@ __osm_mftr_rcv_by_comp_mask(IN cl_map_item_t * const p_map_item,
 	/* compare the lids - if required */
 	if (comp_mask & IB_MFTR_COMPMASK_LID) {
 		OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-			"Comparing lid:0x%02X to port lid range: 0x%02X .. 0x%02X\n",
+			"Comparing lid:%u to port lid range: %u .. %u\n",
 			cl_ntoh16(p_rcvd_rec->lid), min_lid_ho, max_lid_ho);
 		/* ok we are ready for range check */
 		if (min_lid_ho > cl_ntoh16(p_rcvd_rec->lid) ||
diff --git a/opensm/opensm/osm_sa_multipath_record.c b/opensm/opensm/osm_sa_multipath_record.c
index bad1962..86a1d50 100644
--- a/opensm/opensm/osm_sa_multipath_record.c
+++ b/opensm/opensm/osm_sa_multipath_record.c
@@ -235,7 +235,7 @@ __osm_mpr_rcv_get_path_parms(IN osm_sa_t * sa,
 		p_physp = osm_switch_get_route_by_lid(p_node->sw, dest_lid);
 		if (p_physp == 0) {
 			OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 4514: "
-				"Can't find routing to LID 0x%X from switch for GUID 0x%016"
+				"Can't find routing to LID %u from switch for GUID 0x%016"
 				PRIx64 "\n", dest_lid_ho,
 				cl_ntoh64(osm_node_get_node_guid(p_node)));
 			status = IB_NOT_FOUND;
@@ -279,7 +279,7 @@ __osm_mpr_rcv_get_path_parms(IN osm_sa_t * sa,
 
 		if (p_dest_physp == 0) {
 			OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 4515: "
-				"Can't find routing to LID 0x%X from switch for GUID 0x%016"
+				"Can't find routing to LID %u from switch for GUID 0x%016"
 				PRIx64 "\n", dest_lid_ho,
 				cl_ntoh64(osm_node_get_node_guid(p_node)));
 			status = IB_NOT_FOUND;
@@ -299,7 +299,7 @@ __osm_mpr_rcv_get_path_parms(IN osm_sa_t * sa,
 
 		if (p_physp == 0) {
 			OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 4505: "
-				"Can't find remote phys port when routing to LID 0x%X from node GUID 0x%016"
+				"Can't find remote phys port when routing to LID %u from node GUID 0x%016"
 				PRIx64 "\n", dest_lid_ho,
 				cl_ntoh64(osm_node_get_node_guid(p_node)));
 			status = IB_ERROR;
@@ -346,7 +346,7 @@ __osm_mpr_rcv_get_path_parms(IN osm_sa_t * sa,
 		p_physp = osm_switch_get_route_by_lid(p_node->sw, dest_lid);
 		if (p_physp == 0) {
 			OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 4516: "
-				"Dead end on path to LID 0x%X from switch for GUID 0x%016"
+				"Dead end on path to LID %u from switch for GUID 0x%016"
 				PRIx64 "\n", dest_lid_ho,
 				cl_ntoh64(osm_node_get_node_guid(p_node)));
 			status = IB_ERROR;
@@ -822,7 +822,7 @@ __osm_mpr_rcv_get_lid_pair_path(IN osm_sa_t * sa,
 
 	if (osm_log_is_active(sa->p_log, OSM_LOG_DEBUG))
 		OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-			"Src LID 0x%X, Dest LID 0x%X\n",
+			"Src LID %u, Dest LID %u\n",
 			src_lid_ho, dest_lid_ho);
 
 	p_pr_item = malloc(sizeof(*p_pr_item));
@@ -974,7 +974,7 @@ __osm_mpr_rcv_get_port_pair_paths(IN osm_sa_t * sa,
 
 	if (osm_log_is_active(sa->p_log, OSM_LOG_DEBUG))
 		OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-			"Src LID [0x%X-0x%X], Dest LID [0x%X-0x%X]\n",
+			"Src LID [%u-%u], Dest LID [%u-%u]\n",
 			src_lid_min_ho, src_lid_max_ho,
 			dest_lid_min_ho, dest_lid_max_ho);
 
@@ -1122,8 +1122,8 @@ __osm_mpr_rcv_get_apm_port_pair_paths(IN osm_sa_t * sa,
 	dest_lid_ho += base_offs % dest_lids;
 
 	OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-		"Src LIDs [0x%X-0x%X] hashed %d, "
-		"Dest LIDs [0x%X-0x%X] hashed %d\n",
+		"Src LIDs [%u-%u] hashed %u, "
+		"Dest LIDs [%u-%u] hashed %u\n",
 		src_lid_min_ho, src_lid_max_ho, src_lid_ho,
 		dest_lid_min_ho, dest_lid_max_ho, dest_lid_ho);
 
@@ -1142,7 +1142,7 @@ __osm_mpr_rcv_get_apm_port_pair_paths(IN osm_sa_t * sa,
 
 		if (p_pr_item) {
 			OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-				"Found matching path from Src LID 0x%X to Dest LID 0x%X with %d hops\n",
+				"Found matching path from Src LID %u to Dest LID %u with %d hops\n",
 				src_lid_ho, dest_lid_ho, p_pr_item->hops);
 			break;
 		}
diff --git a/opensm/opensm/osm_sa_node_record.c b/opensm/opensm/osm_sa_node_record.c
index 91b748b..1ba418e 100644
--- a/opensm/opensm/osm_sa_node_record.c
+++ b/opensm/opensm/osm_sa_node_record.c
@@ -135,7 +135,7 @@ __osm_nr_rcv_create_nr(IN osm_sa_t * sa,
 
 	if (osm_log_is_active(sa->p_log, OSM_LOG_DEBUG)) {
 		OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-			"Looking for NodeRecord with LID: 0x%X GUID:0x%016"
+			"Looking for NodeRecord with LID: %u GUID:0x%016"
 			PRIx64 "\n", cl_ntoh16(match_lid),
 			cl_ntoh64(match_port_guid)
 		    );
@@ -177,7 +177,7 @@ __osm_nr_rcv_create_nr(IN osm_sa_t * sa,
 			 */
 			if (osm_log_is_active(sa->p_log, OSM_LOG_DEBUG)) {
 				OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-					"Comparing LID: 0x%X <= 0x%X <= 0x%X\n",
+					"Comparing LID: %u <= %u <= %u\n",
 					base_lid_ho, match_lid_ho, max_lid_ho);
 			}
 
diff --git a/opensm/opensm/osm_sa_path_record.c b/opensm/opensm/osm_sa_path_record.c
index 9af8a4f..f863735 100644
--- a/opensm/opensm/osm_sa_path_record.c
+++ b/opensm/opensm/osm_sa_path_record.c
@@ -242,7 +242,7 @@ __osm_pr_rcv_get_path_parms(IN osm_sa_t * sa,
 		p_physp = osm_switch_get_route_by_lid(p_node->sw, dest_lid);
 		if (p_physp == 0) {
 			OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 1F02: "
-				"Cannot find routing to LID 0x%X from switch for GUID 0x%016"
+				"Cannot find routing to LID %u from switch for GUID 0x%016"
 				PRIx64 "\n", dest_lid_ho,
 				cl_ntoh64(osm_node_get_node_guid(p_node)));
 			status = IB_NOT_FOUND;
@@ -286,7 +286,7 @@ __osm_pr_rcv_get_path_parms(IN osm_sa_t * sa,
 
 		if (p_dest_physp == 0) {
 			OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 1F03: "
-				"Cannot find routing to LID 0x%X from switch for GUID 0x%016"
+				"Cannot find routing to LID %u from switch for GUID 0x%016"
 				PRIx64 "\n", dest_lid_ho,
 				cl_ntoh64(osm_node_get_node_guid(p_node)));
 			status = IB_NOT_FOUND;
@@ -306,7 +306,7 @@ __osm_pr_rcv_get_path_parms(IN osm_sa_t * sa,
 
 		if (p_physp == 0) {
 			OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 1F05: "
-				"Cannot find remote phys port when routing to LID 0x%X from node GUID 0x%016"
+				"Cannot find remote phys port when routing to LID %u from node GUID 0x%016"
 				PRIx64 "\n", dest_lid_ho,
 				cl_ntoh64(osm_node_get_node_guid(p_node)));
 			status = IB_ERROR;
@@ -352,7 +352,7 @@ __osm_pr_rcv_get_path_parms(IN osm_sa_t * sa,
 		p_physp = osm_switch_get_route_by_lid(p_node->sw, dest_lid);
 		if (p_physp == 0) {
 			OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 1F07: "
-				"Dead end on path to LID 0x%X from switch for GUID 0x%016"
+				"Dead end on path to LID %u from switch for GUID 0x%016"
 				PRIx64 "\n", dest_lid_ho,
 				cl_ntoh64(osm_node_get_node_guid(p_node)));
 			status = IB_ERROR;
@@ -847,7 +847,7 @@ __osm_pr_rcv_get_lid_pair_path(IN osm_sa_t * sa,
 
 	if (osm_log_is_active(sa->p_log, OSM_LOG_DEBUG))
 		OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-			"Src LID 0x%X, Dest LID 0x%X\n",
+			"Src LID %u, Dest LID %u\n",
 			src_lid_ho, dest_lid_ho);
 
 	p_pr_item = malloc(sizeof(*p_pr_item));
@@ -1026,7 +1026,7 @@ __osm_pr_rcv_get_port_pair_paths(IN osm_sa_t * sa,
 
 	if (osm_log_is_active(sa->p_log, OSM_LOG_DEBUG))
 		OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-			"Src LIDs [0x%X-0x%X], Dest LIDs [0x%X-0x%X]\n",
+			"Src LIDs [%u-%u], Dest LIDs [%u-%u]\n",
 			src_lid_min_ho, src_lid_max_ho,
 			dest_lid_min_ho, dest_lid_max_ho);
 
@@ -1221,7 +1221,7 @@ __osm_pr_rcv_get_end_points(IN osm_sa_t * sa,
 				   Return an error response to the client.
 				 */
 				OSM_LOG(sa->p_log, OSM_LOG_VERBOSE,
-					"No source port with LID 0x%X\n",
+					"No source port with LID %u\n",
 					cl_ntoh16(p_pr->slid));
 
 				sa_status = IB_SA_MAD_STATUS_NO_RECORDS;
@@ -1332,7 +1332,7 @@ __osm_pr_rcv_get_end_points(IN osm_sa_t * sa,
 				   Return an error response to the client.
 				 */
 				OSM_LOG(sa->p_log, OSM_LOG_VERBOSE,
-					"No dest port with LID 0x%X\n",
+					"No dest port with LID %u\n",
 					cl_ntoh16(p_pr->dlid));
 
 				sa_status = IB_SA_MAD_STATUS_NO_RECORDS;
diff --git a/opensm/opensm/osm_sa_pkey_record.c b/opensm/opensm/osm_sa_pkey_record.c
index d953369..db341f1 100644
--- a/opensm/opensm/osm_sa_pkey_record.c
+++ b/opensm/opensm/osm_sa_pkey_record.c
@@ -301,7 +301,7 @@ void osm_pkey_rec_rcv_process(IN void *ctx, IN void *data)
 	context.p_req_physp = p_req_physp;
 
 	OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-		"Got Query Lid:0x%04X(%02X), Block:0x%02X(%02X), Port:0x%02X(%02X)\n",
+		"Got Query Lid:%u(%02X), Block:0x%02X(%02X), Port:0x%02X(%02X)\n",
 		cl_ntoh16(p_rcvd_rec->lid),
 		(comp_mask & IB_PKEY_COMPMASK_LID) != 0, p_rcvd_rec->port_num,
 		(comp_mask & IB_PKEY_COMPMASK_PORT) != 0, p_rcvd_rec->block_num,
@@ -324,7 +324,7 @@ void osm_pkey_rec_rcv_process(IN void *ctx, IN void *data)
 		if (status != IB_SUCCESS || p_port == NULL) {
 			status = IB_NOT_FOUND;
 			OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 460B: "
-				"No port found with LID 0x%x\n",
+				"No port found with LID %u\n",
 				cl_ntoh16(p_rcvd_rec->lid));
 		}
 	}
diff --git a/opensm/opensm/osm_sa_portinfo_record.c b/opensm/opensm/osm_sa_portinfo_record.c
index 3f3163d..267fe4a 100644
--- a/opensm/opensm/osm_sa_portinfo_record.c
+++ b/opensm/opensm/osm_sa_portinfo_record.c
@@ -149,7 +149,7 @@ __osm_sa_pir_create(IN osm_sa_t * sa,
 		 */
 		if (osm_log_is_active(sa->p_log, OSM_LOG_DEBUG))
 			OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-				"Comparing LID: 0x%X <= 0x%X <= 0x%X\n",
+				"Comparing LID: %u <= %u <= %u\n",
 				base_lid_ho, match_lid_ho, max_lid_ho);
 
 		if (match_lid_ho < base_lid_ho || match_lid_ho > max_lid_ho)
@@ -543,7 +543,7 @@ void osm_pir_rcv_process(IN void *ctx, IN void *data)
 		if ((status != IB_SUCCESS) || (p_port == NULL)) {
 			status = IB_NOT_FOUND;
 			OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 2109: "
-				"No port found with LID 0x%x\n",
+				"No port found with LID %u\n",
 				cl_ntoh16(p_rcvd_rec->lid));
 		}
 	} else if (comp_mask & IB_PIR_COMPMASK_BASELID) {
@@ -554,7 +554,7 @@ void osm_pir_rcv_process(IN void *ctx, IN void *data)
 		else {
 			status = IB_NOT_FOUND;
 			OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 2103: "
-				"Given LID (0x%X) is out of range:0x%X\n",
+				"Given LID (%u) is out of range:%u\n",
 				cl_ntoh16(p_pi->base_lid),
 				cl_ptr_vector_get_size(p_tbl));
 		}
diff --git a/opensm/opensm/osm_sa_slvl_record.c b/opensm/opensm/osm_sa_slvl_record.c
index f3b53dc..0b33307 100644
--- a/opensm/opensm/osm_sa_slvl_record.c
+++ b/opensm/opensm/osm_sa_slvl_record.c
@@ -272,7 +272,7 @@ void osm_slvl_rec_rcv_process(IN void *ctx, IN void *data)
 	cl_plock_acquire(sa->p_lock);
 
 	OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-		"Got Query Lid:0x%04X(%02X), In-Port:0x%02X(%02X), Out-Port:0x%02X(%02X)\n",
+		"Got Query Lid:%u(%02X), In-Port:0x%02X(%02X), Out-Port:0x%02X(%02X)\n",
 		cl_ntoh16(p_rcvd_rec->lid),
 		(comp_mask & IB_SLVL_COMPMASK_LID) != 0,
 		p_rcvd_rec->in_port_num,
@@ -296,7 +296,7 @@ void osm_slvl_rec_rcv_process(IN void *ctx, IN void *data)
 		if ((status != IB_SUCCESS) || (p_port == NULL)) {
 			status = IB_NOT_FOUND;
 			OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 2608: "
-				"No port found with LID 0x%x\n",
+				"No port found with LID %u\n",
 				cl_ntoh16(p_rcvd_rec->lid));
 		}
 	}
diff --git a/opensm/opensm/osm_sa_sminfo_record.c b/opensm/opensm/osm_sa_sminfo_record.c
index 6eddc59..f23c3e0 100644
--- a/opensm/opensm/osm_sa_sminfo_record.c
+++ b/opensm/opensm/osm_sa_sminfo_record.c
@@ -252,7 +252,7 @@ void osm_smir_rcv_process(IN void *ctx, IN void *data)
 		if ((status != IB_SUCCESS) || (p_port == NULL)) {
 			status = IB_NOT_FOUND;
 			OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 2806: "
-				"No port found with LID 0x%x\n",
+				"No port found with LID %u\n",
 				cl_ntoh16(p_rcvd_rec->lid));
 		}
 	}
diff --git a/opensm/opensm/osm_sa_sw_info_record.c b/opensm/opensm/osm_sa_sw_info_record.c
index a05c814..86471e3 100644
--- a/opensm/opensm/osm_sa_sw_info_record.c
+++ b/opensm/opensm/osm_sa_sw_info_record.c
@@ -143,7 +143,7 @@ __osm_sir_rcv_create_sir(IN osm_sa_t * sa,
 
 	if (osm_log_is_active(sa->p_log, OSM_LOG_DEBUG)) {
 		OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-			"Looking for SwitchInfoRecord with LID: 0x%X\n",
+			"Looking for SwitchInfoRecord with LID: %u\n",
 			cl_ntoh16(match_lid)
 		    );
 	}
@@ -184,7 +184,7 @@ __osm_sir_rcv_create_sir(IN osm_sa_t * sa,
 		 */
 		if (osm_log_is_active(sa->p_log, OSM_LOG_DEBUG)) {
 			OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-				"Comparing LID: 0x%X <= 0x%X <= 0x%X\n",
+				"Comparing LID: %u <= %u <= %u\n",
 				min_lid_ho, match_lid_ho, max_lid_ho);
 		}
 
diff --git a/opensm/opensm/osm_sa_vlarb_record.c b/opensm/opensm/osm_sa_vlarb_record.c
index 6b97a2e..eb4dd81 100644
--- a/opensm/opensm/osm_sa_vlarb_record.c
+++ b/opensm/opensm/osm_sa_vlarb_record.c
@@ -287,7 +287,7 @@ void osm_vlarb_rec_rcv_process(IN void *ctx, IN void *data)
 	context.p_req_physp = p_req_physp;
 
 	OSM_LOG(sa->p_log, OSM_LOG_DEBUG,
-		"Got Query Lid:0x%04X(%02X), Port:0x%02X(%02X), Block:0x%02X(%02X)\n",
+		"Got Query Lid:%u(%02X), Port:0x%02X(%02X), Block:0x%02X(%02X)\n",
 		cl_ntoh16(p_rcvd_rec->lid),
 		(comp_mask & IB_VLA_COMPMASK_LID) != 0, p_rcvd_rec->port_num,
 		(comp_mask & IB_VLA_COMPMASK_OUT_PORT) != 0,
@@ -312,7 +312,7 @@ void osm_vlarb_rec_rcv_process(IN void *ctx, IN void *data)
 		if ((status != IB_SUCCESS) || (p_port == NULL)) {
 			status = IB_NOT_FOUND;
 			OSM_LOG(sa->p_log, OSM_LOG_ERROR, "ERR 2A09: "
-				"No port found with LID 0x%x\n",
+				"No port found with LID %u\n",
 				cl_ntoh16(p_rcvd_rec->lid));
 		}
 	}
diff --git a/opensm/opensm/osm_state_mgr.c b/opensm/opensm/osm_state_mgr.c
index 780d8db..9a8409b 100644
--- a/opensm/opensm/osm_state_mgr.c
+++ b/opensm/opensm/osm_state_mgr.c
@@ -833,7 +833,7 @@ static void __osm_state_mgr_report_new_ports(IN osm_sm_t * sm)
 		osm_port_get_lid_range_ho(p_port, &min_lid_ho, &max_lid_ho);
 		OSM_LOG(sm->p_log, OSM_LOG_INFO,
 			"Discovered new port with GUID:0x%016" PRIx64
-			" LID range [0x%X,0x%X] of node:%s\n",
+			" LID range [%u,%u] of node:%s\n",
 			cl_ntoh64(port_gid.unicast.interface_id),
 			min_lid_ho, max_lid_ho,
 			p_port->p_node ? p_port->p_node->
diff --git a/opensm/opensm/osm_subnet.c b/opensm/opensm/osm_subnet.c
index 73b476f..976e12b 100644
--- a/opensm/opensm/osm_subnet.c
+++ b/opensm/opensm/osm_subnet.c
@@ -243,7 +243,7 @@ osm_get_gid_by_mad_addr(IN osm_log_t * p_log,
 		    cl_ptr_vector_get(p_tbl, cl_ntoh16(p_mad_addr->dest_lid));
 		if (p_port == NULL) {
 			OSM_LOG(p_log, OSM_LOG_DEBUG,
-				"Did not find any port with LID: 0x%X\n",
+				"Did not find any port with LID: %u\n",
 				cl_ntoh16(p_mad_addr->dest_lid));
 			return (IB_INVALID_PARAMETER);
 		}
@@ -252,7 +252,7 @@ osm_get_gid_by_mad_addr(IN osm_log_t * p_log,
 	} else {
 		/* The dest_lid is not in the subnet table - this is an error */
 		OSM_LOG(p_log, OSM_LOG_ERROR, "ERR 7501: "
-			"LID is out of range: 0x%X\n",
+			"LID is out of range: %u\n",
 			cl_ntoh16(p_mad_addr->dest_lid));
 		return (IB_INVALID_PARAMETER);
 	}
@@ -283,7 +283,7 @@ osm_physp_t *osm_get_physp_by_mad_addr(IN osm_log_t * p_log,
 		if (p_port == NULL) {
 			/* The port is not in the port_lid table - this is an error */
 			OSM_LOG(p_log, OSM_LOG_ERROR, "ERR 7502: "
-				"Cannot locate port object by lid: 0x%X\n",
+				"Cannot locate port object by lid: %u\n",
 				cl_ntoh16(p_mad_addr->dest_lid));
 
 			goto Exit;
@@ -292,7 +292,7 @@ osm_physp_t *osm_get_physp_by_mad_addr(IN osm_log_t * p_log,
 	} else {
 		/* The dest_lid is not in the subnet table - this is an error */
 		OSM_LOG(p_log, OSM_LOG_ERROR, "ERR 7503: "
-			"Lid is out of range: 0x%X\n",
+			"Lid is out of range: %u\n",
 			cl_ntoh16(p_mad_addr->dest_lid));
 	}
 
@@ -322,7 +322,7 @@ osm_port_t *osm_get_port_by_mad_addr(IN osm_log_t * p_log,
 	} else {
 		/* The dest_lid is not in the subnet table - this is an error */
 		OSM_LOG(p_log, OSM_LOG_ERROR, "ERR 7504: "
-			"Lid is out of range: 0x%X\n",
+			"Lid is out of range: %u\n",
 			cl_ntoh16(p_mad_addr->dest_lid));
 	}
 
diff --git a/opensm/opensm/osm_trap_rcv.c b/opensm/opensm/osm_trap_rcv.c
index 1ff8e6e..ae7ab05 100644
--- a/opensm/opensm/osm_trap_rcv.c
+++ b/opensm/opensm/osm_trap_rcv.c
@@ -310,7 +310,7 @@ __osm_trap_rcv_process_request(IN osm_sm_t * sm,
 				goto Exit;
 			}
 			OSM_LOG(sm->p_log, OSM_LOG_DEBUG,
-				"Received SLID=0 Trap. Using local LID:0x%04X instead\n",
+				"Received SLID=0 Trap. Using local LID:%u instead\n",
 				cl_ntoh16(sm->p_subn->sm_base_lid)
 			    );
 			tmp_madw.mad_addr.addr_type.smi.source_lid =
@@ -328,7 +328,7 @@ __osm_trap_rcv_process_request(IN osm_sm_t * sm,
 				CL_HTON16(131)))
 				OSM_LOG(sm->p_log, OSM_LOG_ERROR,
 					"Received Generic Notice type:0x%02X num:%u Producer:%u (%s) "
-					"from LID:0x%04X Port %d TID:0x%016"
+					"from LID:%u Port %d TID:0x%016"
 					PRIx64 "\n", ib_notice_get_type(p_ntci),
 					cl_ntoh16(p_ntci->g_or_v.generic.
 						  trap_num),
@@ -343,7 +343,7 @@ __osm_trap_rcv_process_request(IN osm_sm_t * sm,
 			else
 				OSM_LOG(sm->p_log, OSM_LOG_ERROR,
 					"Received Generic Notice type:0x%02X num:%u Producer:%u (%s) "
-					"from LID:0x%04X TID:0x%016" PRIx64
+					"from LID:%u TID:0x%016" PRIx64
 					"\n", ib_notice_get_type(p_ntci),
 					cl_ntoh16(p_ntci->g_or_v.generic.
 						  trap_num),
@@ -357,7 +357,7 @@ __osm_trap_rcv_process_request(IN osm_sm_t * sm,
 		} else
 			OSM_LOG(sm->p_log, OSM_LOG_ERROR,
 				"Received Vendor Notice type:0x%02X vend:0x%06X dev:%u "
-				"from LID:0x%04X TID:0x%016" PRIx64 "\n",
+				"from LID:%u TID:0x%016" PRIx64 "\n",
 				ib_notice_get_type(p_ntci),
 				cl_ntoh32(ib_notice_get_vend_id(p_ntci)),
 				cl_ntoh16(p_ntci->g_or_v.vend.dev_id),
@@ -442,7 +442,7 @@ __osm_trap_rcv_process_request(IN osm_sm_t * sm,
 				if (!p_physp)
 					OSM_LOG(sm->p_log, OSM_LOG_ERROR,
 						"ERR 3805: "
-						"Failed to find physical port by lid:0x%02X num:%u\n",
+						"Failed to find physical port by lid:%u num:%u\n",
 						cl_ntoh16(p_ntci->data_details.
 							  ntc_129_131.lid),
 						p_ntci->data_details.
@@ -465,7 +465,7 @@ __osm_trap_rcv_process_request(IN osm_sm_t * sm,
 
 						OSM_LOG(sm->p_log, OSM_LOG_ERROR,
 							"ERR 3810: "
-							"Disabling physical port lid:0x%02X num:%u\n",
+							"Disabling physical port lid:%u num:%u\n",
 							cl_ntoh16(p_ntci->
 								  data_details.
 								  ntc_129_131.
@@ -524,7 +524,7 @@ __osm_trap_rcv_process_request(IN osm_sm_t * sm,
 					}
 
 					OSM_LOG(sm->p_log, OSM_LOG_VERBOSE,
-						"Marking unhealthy physical port by lid:0x%02X num:%u\n",
+						"Marking unhealthy physical port by lid:%u num:%u\n",
 						cl_ntoh16(p_ntci->data_details.
 							  ntc_129_131.lid),
 						p_ntci->data_details.
@@ -640,7 +640,7 @@ __osm_trap_rcv_process_request(IN osm_sm_t * sm,
 		    cl_ntoh16(source_lid)) {
 			/*  the source lid is out of range */
 			OSM_LOG(sm->p_log, OSM_LOG_VERBOSE,
-				"source lid is out of range:0x%X\n",
+				"source lid is out of range:%u\n",
 				cl_ntoh16(source_lid));
 
 			goto Exit;
@@ -649,7 +649,7 @@ __osm_trap_rcv_process_request(IN osm_sm_t * sm,
 		if (p_port == 0) {
 			/* We have the lid - but no corresponding port */
 			OSM_LOG(sm->p_log, OSM_LOG_VERBOSE,
-				"Cannot find port corresponding to lid:0x%X\n",
+				"Cannot find port corresponding to lid:%u\n",
 				cl_ntoh16(source_lid));
 
 			goto Exit;
diff --git a/opensm/opensm/osm_ucast_file.c b/opensm/opensm/osm_ucast_file.c
index 43bcbc5..dee0e01 100644
--- a/opensm/opensm/osm_ucast_file.c
+++ b/opensm/opensm/osm_ucast_file.c
@@ -86,7 +86,7 @@ static void add_path(osm_opensm_t * p_osm,
 	if (old_port != OSM_NO_PATH && old_port != port_num) {
 		OSM_LOG(&p_osm->log, OSM_LOG_VERBOSE,
 			"LID collision is detected on switch "
-			"0x016%" PRIx64 ", will overwrite LID 0x%x entry\n",
+			"0x016%" PRIx64 ", will overwrite LID %u entry\n",
 			cl_ntoh64(osm_node_get_node_guid(p_sw->p_node)),
 			new_lid);
 	}
diff --git a/opensm/opensm/osm_ucast_mgr.c b/opensm/opensm/osm_ucast_mgr.c
index 39ce2bd..9f54486 100644
--- a/opensm/opensm/osm_ucast_mgr.c
+++ b/opensm/opensm/osm_ucast_mgr.c
@@ -246,7 +246,7 @@ __osm_ucast_mgr_process_port(IN osm_ucast_mgr_t * const p_mgr,
 
 	if (osm_log_is_active(p_mgr->p_log, OSM_LOG_DEBUG))
 		OSM_LOG(p_mgr->p_log, OSM_LOG_DEBUG,
-			"Processing port 0x%" PRIx64 " (\'%s\' port %u), LID %u [0x%X,0x%X]\n",
+			"Processing port 0x%" PRIx64 " (\'%s\' port %u), LID %u [%u,%u]\n",
 			cl_ntoh64(osm_port_get_guid(p_port)),
 			p_port->p_node->print_desc, p_port->p_physp->port_num,
 			lid_ho, min_lid_ho, max_lid_ho);
@@ -276,17 +276,17 @@ __osm_ucast_mgr_process_port(IN osm_ucast_mgr_t * const p_mgr,
 		   switches so we do not report that as an error in that case */
 		if (!p_routing_eng->build_lid_matrices) {
 			OSM_LOG(p_mgr->p_log, OSM_LOG_ERROR, "ERR 3A08: "
-				"No path to get to LID 0x%X from switch 0x%"
+				"No path to get to LID %u from switch 0x%"
 				PRIx64 "\n", lid_ho, cl_ntoh64(node_guid));
 			/* trigger a new sweep - try again ... */
 			p_mgr->p_subn->subnet_initialization_error = TRUE;
 		} else
 			OSM_LOG(p_mgr->p_log, OSM_LOG_DEBUG,
-				"No path to get to LID 0x%X from switch 0x%"
+				"No path to get to LID %u from switch 0x%"
 				PRIx64 "\n", lid_ho, cl_ntoh64(node_guid));
 	} else {
 		OSM_LOG(p_mgr->p_log, OSM_LOG_DEBUG,
-			"Routing LID 0x%X to port 0x%X"
+			"Routing LID %u to port 0x%X"
 			" for switch 0x%" PRIx64 "\n",
 			lid_ho, port, cl_ntoh64(node_guid));
 
@@ -384,7 +384,7 @@ osm_ucast_mgr_set_fwd_table(IN osm_ucast_mgr_t * const p_mgr,
 	if (set_swinfo_require) {
 		if (osm_log_is_active(p_mgr->p_log, OSM_LOG_DEBUG)) {
 			OSM_LOG(p_mgr->p_log, OSM_LOG_DEBUG,
-				"Setting switch FT top to LID 0x%X\n",
+				"Setting switch FT top to LID %u\n",
 				p_sw->max_lid_ho);
 		}
 






More information about the general mailing list
diff --git a/opensm/opensm/osm_ucast_ftree.c b/opensm/opensm/osm_ucast_ftree.c
index 9604381..7502e04 100644
--- a/opensm/opensm/osm_ucast_ftree.c
+++ b/opensm/opensm/osm_ucast_ftree.c
@@ -55,7 +55,7 @@
 
 /*
  * FatTree rank is bounded between 2 and 8:
  *  - Tree of rank 1 has only trivial routing pathes,
  *    so no need to use FatTree routing.
  *  - Why maximum rank is 8:
  *    Each node (switch) is assigned a unique tuple.
@@ -1222,7 +1222,7 @@ static void __osm_ftree_fabric_dump_general_info(IN ftree_fabric_t * p_ftree)
 			if (p_sw->rank == 0)
 				OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_VERBOSE,
 					"      GUID: 0x%016" PRIx64
-					", LID: 0x%04x, Index %s\n",
+					", LID: %u, Index %s\n",
 					__osm_ftree_sw_get_guid_ho(p_sw),
 					cl_ntoh16(p_sw->base_lid),
 					__osm_ftree_tuple_to_str(p_sw->tuple));
@@ -1233,7 +1233,7 @@ static void __osm_ftree_fabric_dump_general_info(IN ftree_fabric_t * p_ftree)
 		for (i = 0; i < p_ftree->leaf_switches_num; i++) {
 			OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_VERBOSE,
 				"      GUID: 0x%016" PRIx64
-				", LID: 0x%04x, Index %s\n",
+				", LID: %u, Index %s\n",
 				__osm_ftree_sw_get_guid_ho(p_ftree->
 							   leaf_switches[i]),
 				cl_ntoh16(p_ftree->leaf_switches[i]->base_lid),
@@ -1492,7 +1492,7 @@ static void __osm_ftree_fabric_make_indexing(IN ftree_fabric_t * p_ftree)
 		"Indexing starting point:\n"
 		"                                            - Switch rank  : %u\n"
 		"                                            - Switch index : %s\n"
-		"                                            - Node LID     : 0x%04x\n"
+		"                                            - Node LID     : %u\n"
 		"                                            - Node GUID    : 0x%016"
 		PRIx64 "\n", p_sw->rank, __osm_ftree_tuple_to_str(p_sw->tuple),
 		cl_ntoh16(p_sw->base_lid), __osm_ftree_sw_get_guid_ho(p_sw));
@@ -1778,9 +1778,9 @@ static boolean_t __osm_ftree_fabric_validate_topology(IN ftree_fabric_t *
 				OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_ERROR,
 					"ERR AB09: Different number of upward port groups on switches:\n"
 					"       GUID 0x%016" PRIx64
-					", LID 0x%04x, Index %s - %u groups\n"
+					", LID %u, Index %s - %u groups\n"
 					"       GUID 0x%016" PRIx64
-					", LID 0x%04x, Index %s - %u groups\n",
+					", LID %u, Index %s - %u groups\n",
 					__osm_ftree_sw_get_guid_ho
 					(reference_sw_arr[p_sw->rank]),
 					cl_ntoh16(reference_sw_arr[p_sw->rank]->
@@ -1805,9 +1805,9 @@ static boolean_t __osm_ftree_fabric_validate_topology(IN ftree_fabric_t *
 				OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_ERROR,
 					"ERR AB0A: Different number of downward port groups on switches:\n"
 					"       GUID 0x%016" PRIx64
-					", LID 0x%04x, Index %s - %u port groups\n"
+					", LID %u, Index %s - %u port groups\n"
 					"       GUID 0x%016" PRIx64
-					", LID 0x%04x, Index %s - %u port groups\n",
+					", LID %u, Index %s - %u port groups\n",
 					__osm_ftree_sw_get_guid_ho
 					(reference_sw_arr[p_sw->rank]),
 					cl_ntoh16(reference_sw_arr[p_sw->rank]->
@@ -1840,10 +1840,10 @@ static boolean_t __osm_ftree_fabric_validate_topology(IN ftree_fabric_t *
 							"ERR AB0B: Different number of ports in an upward port group on switches:\n"
 							"       GUID 0x%016"
 							PRIx64
-							", LID 0x%04x, Index %s - %u ports\n"
+							", LID %u, Index %s - %u ports\n"
 							"       GUID 0x%016"
 							PRIx64
-							", LID 0x%04x, Index %s - %u ports\n",
+							", LID %u, Index %s - %u ports\n",
 							__osm_ftree_sw_get_guid_ho
 							(reference_sw_arr
 							 [p_sw->rank]),
@@ -1887,10 +1887,10 @@ static boolean_t __osm_ftree_fabric_validate_topology(IN ftree_fabric_t *
 							"ERR AB0C: Different number of ports in an downward port group on switches:\n"
 							"       GUID 0x%016"
 							PRIx64
-							", LID 0x%04x, Index %s - %u ports\n"
+							", LID %u, Index %s - %u ports\n"
 							"       GUID 0x%016"
 							PRIx64
-							", LID 0x%04x, Index %s - %u ports\n",
+							", LID %u, Index %s - %u ports\n",
 							__osm_ftree_sw_get_guid_ho
 							(reference_sw_arr
 							 [p_sw->rank]),
@@ -2045,7 +2045,7 @@ __osm_ftree_fabric_route_upgoing_by_going_down(IN ftree_fabric_t * p_ftree,
 			   on our way UP, and now we see it again on our way DOWN */
 			OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_DEBUG,
 				"Loop of lenght %d in the fabric:\n                             "
-				"Switch %s (LID 0x%04x) closes loop through switch %s (LID 0x%04x)\n",
+				"Switch %s (LID %u) closes loop through switch %s (LID %u)\n",
 				(p_remote_sw->rank - highest_rank_in_route) * 2,
 				__osm_ftree_tuple_to_str(p_remote_sw->tuple),
 				cl_ntoh16(p_group->base_lid),
@@ -2097,7 +2097,7 @@ __osm_ftree_fabric_route_upgoing_by_going_down(IN ftree_fabric_t * p_ftree,
 							   p_min_port->
 							   remote_port_num);
 			OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_DEBUG,
-				"Switch %s: set path to CA LID 0x%04x through port %u\n",
+				"Switch %s: set path to CA LID %u through port %u\n",
 				__osm_ftree_tuple_to_str(p_remote_sw->tuple),
 				cl_ntoh16(target_lid),
 				p_min_port->remote_port_num);
@@ -2260,7 +2260,7 @@ __osm_ftree_fabric_route_downgoing_by_going_up(IN ftree_fabric_t * p_ftree,
 	if (is_main_path) {
 		if (p_sw->is_leaf) {
 			OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_DEBUG,
-				" - Routing MAIN path for %s CA LID 0x%04x: %s --> %s\n",
+				" - Routing MAIN path for %s CA LID %u: %s --> %s\n",
 				(is_real_lid) ? "real" : "DUMMY",
 				cl_ntoh16(target_lid),
 				__osm_ftree_tuple_to_str(p_sw->tuple),
@@ -2279,7 +2279,7 @@ __osm_ftree_fabric_route_downgoing_by_going_up(IN ftree_fabric_t * p_ftree,
 							   p_min_port->
 							   remote_port_num);
 			OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_DEBUG,
-				"Switch %s: set path to CA LID 0x%04x through port %u\n",
+				"Switch %s: set path to CA LID %u through port %u\n",
 				__osm_ftree_tuple_to_str(p_remote_sw->tuple),
 				cl_ntoh16(target_lid),
 				p_min_port->remote_port_num);
@@ -2358,7 +2358,7 @@ __osm_ftree_fabric_route_downgoing_by_going_up(IN ftree_fabric_t * p_ftree,
 
 		if (p_sw->is_leaf) {
 			OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_DEBUG,
-				" - Routing SECONDARY path for LID 0x%04x: %s --> %s\n",
+				" - Routing SECONDARY path for LID %u: %s --> %s\n",
 				cl_ntoh16(target_lid),
 				__osm_ftree_tuple_to_str(p_sw->tuple),
 				__osm_ftree_tuple_to_str(p_remote_sw->tuple));
@@ -2368,7 +2368,7 @@ __osm_ftree_fabric_route_downgoing_by_going_up(IN ftree_fabric_t * p_ftree,
 		   switch-to-switch or switch-to-CA paths.
 		   We can safely assume that switch will initiate very
 		   few traffic, so there's no point waisting runtime on
-		   trying to ballance these routes - always pick port 0. */
+		   trying to balance these routes - always pick port 0. */
 
 		cl_ptr_vector_at(&p_group->ports, 0, (void **)&p_port);
 		__osm_ftree_sw_set_fwd_table_block(p_remote_sw,
@@ -2468,7 +2468,7 @@ static void __osm_ftree_fabric_route_to_cns(IN ftree_fabric_t * p_ftree)
 							   cl_ntoh16(hca_lid),
 							   p_port->port_num);
 			OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_DEBUG,
-				"Switch %s: set path to CN LID 0x%04x through port %u\n",
+				"Switch %s: set path to CN LID %u through port %u\n",
 				__osm_ftree_tuple_to_str(p_sw->tuple),
 				cl_ntoh16(hca_lid), p_port->port_num);
 
@@ -2479,7 +2479,7 @@ static void __osm_ftree_fabric_route_to_cns(IN ftree_fabric_t * p_ftree)
 
 			/* Assign downgoing ports by stepping up.
 			   Since we're routing here only CNs, we're routing it as REAL
-			   LID and updating fat-tree ballancing counters. */
+			   LID and updating fat-tree balancing counters. */
 			__osm_ftree_fabric_route_downgoing_by_going_up(p_ftree, p_sw,	/* local switch - used as a route-downgoing alg. start point */
 								       NULL,	/* prev. position switch */
 								       hca_lid,	/* LID that we're routing to */
@@ -2579,7 +2579,7 @@ static void __osm_ftree_fabric_route_to_non_cns(IN ftree_fabric_t * p_ftree)
 							   port_num_on_switch);
 
 			OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_DEBUG,
-				"Switch %s: set path to non-CN HCA LID 0x%04x through port %u\n",
+				"Switch %s: set path to non-CN HCA LID %u through port %u\n",
 				__osm_ftree_tuple_to_str(p_sw->tuple),
 				cl_ntoh16(hca_lid), port_num_on_switch);
 
@@ -2637,7 +2637,7 @@ static void __osm_ftree_fabric_route_to_switches(IN ftree_fabric_t * p_ftree)
 						   0);
 
 		OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_DEBUG,
-			"Switch %s (LID 0x%04x): routing switch-to-switch pathes\n",
+			"Switch %s (LID %u): routing switch-to-switch paths\n",
 			__osm_ftree_tuple_to_str(p_sw->tuple),
 			cl_ntoh16(p_sw->base_lid));
 
@@ -2845,7 +2845,7 @@ __osm_ftree_rank_leaf_switches(IN ftree_fabric_t * p_ftree,
 			PRIx64 "\n"
 			"                                            - Switch guid: 0x%016"
 			PRIx64 "\n"
-			"                                            - Switch LID : 0x%04x\n",
+			"                                            - Switch LID : %u\n",
 			__osm_ftree_hca_get_guid_ho(p_hca),
 			__osm_ftree_sw_get_guid_ho(p_sw),
 			cl_ntoh16(p_sw->base_lid));
@@ -3020,7 +3020,7 @@ static int __osm_ftree_fabric_construct_sw_ports(IN ftree_fabric_t * p_ftree,
 		if (p_node == p_remote_node) {
 			OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_DEBUG,
 				"Ignoring loopback on switch GUID 0x%016" PRIx64
-				", LID 0x%04x, rank %u\n",
+				", LID %u, rank %u\n",
 				__osm_ftree_sw_get_guid_ho(p_sw),
 				cl_ntoh16(p_sw->base_lid),
 				p_sw->rank);
@@ -3065,9 +3065,9 @@ static int __osm_ftree_fabric_construct_sw_ports(IN ftree_fabric_t * p_ftree,
 					"ERR AB16: "
 					"Illegal link between switches with ranks %u and %u:\n"
 					"       GUID 0x%016" PRIx64
-					", LID 0x%04x, rank %u\n"
+					", LID %u, rank %u\n"
 					"       GUID 0x%016" PRIx64
-					", LID 0x%04x, rank %u\n", p_sw->rank,
+					", LID %u, rank %u\n", p_sw->rank,
 					p_remote_sw->rank,
 					__osm_ftree_sw_get_guid_ho(p_sw),
 					cl_ntoh16(p_sw->base_lid), p_sw->rank,
@@ -3647,7 +3647,7 @@ static int __osm_ftree_construct_fabric(IN void *context)
 	}
 
 	OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_VERBOSE,
-		"Max LID in switch LFTs (in host order): 0x%04x\n",
+		"Max LID in switch LFTs: %u\n",
 		p_ftree->lft_max_lid_ho);
 
 Exit:
@@ -3695,7 +3695,7 @@ static int __osm_ftree_do_routing(IN void *context)
 	__osm_ftree_fabric_route_to_non_cns(p_ftree);
 
 	OSM_LOG(&p_ftree->p_osm->log, OSM_LOG_VERBOSE,
-		"Filling switch forwarding tables for switch-to-switch pathes\n");
+		"Filling switch forwarding tables for switch-to-switch paths\n");
 	__osm_ftree_fabric_route_to_switches(p_ftree);
 
 	/* for each switch, set its fwd table */
@@ -55,7 +55,7 @@
 /*
  * FatTree rank is bounded between 2 and 8:
- *  - Tree of rank 1 has only trivial routing pathes,
+ *  - Tree of rank 1 has only trivial routing paths,
  *    so no need to use FatTree routing.
  *  - Why maximum rank is 8: